@@ -239,10 +239,12 @@ static int extra_set(grib_accessor* a, long val)
     int is_instant               = -1;
     long is_chemical             = 0;
     long is_chemical_distfn      = 0;
+    long is_chemical_srcsink     = 0;
     long is_aerosol              = 0;
     long is_aerosol_optical      = 0;
 
     grib_get_long(hand, "is_chemical", &is_chemical);
+    grib_get_long(hand, "is_chemical_srcsink", &is_chemical_srcsink);
     grib_get_long(hand, "is_chemical_distfn", &is_chemical_distfn);
     grib_get_long(hand, "is_aerosol", &is_aerosol);
     grib_get_long(hand, "is_aerosol_optical", &is_aerosol_optical);
@@ -353,6 +355,7 @@ static int extra_set(grib_accessor* a, long val)
                 case 36: /* Probability distribution  (pd)  */
                 case 37: /* Cluster information       (ci)  */
                 case 38: /* Shift of Tail             (sot) */
+                case 39: /* Ensemble data assimilation model errors */
                 case 40: /* Images                    (im)  */
                 case 42: /* Simulated images          (sim) */
                     typeOfProcessedData     = 255;
@@ -396,14 +399,9 @@ static int extra_set(grib_accessor* a, long val)
                     typeOfProcessedData     = 255;
                     typeOfGeneratingProcess = 255;
                     break;
-                case 84: /* Ensemble mean of temporal mean   (emtm) */
-                case 85: /* Ensemble standard deviation of temporal mean  (estdtm) */
-                    typeOfProcessedData     = 255;
-                    typeOfGeneratingProcess = 4;
-                    break;
                 default:
-                    grib_context_log(a->context, GRIB_LOG_ERROR, "unknown mars.type %d", (int)val);
-                    return GRIB_ENCODING_ERROR;
+                    grib_context_log(a->context, GRIB_LOG_WARNING, "g2_mars_labeling: unknown mars.type %d", (int)val);
+                    /*return GRIB_ENCODING_ERROR;*/
             }
             break;
         case 2:
@@ -418,6 +416,7 @@ static int extra_set(grib_accessor* a, long val)
                     productDefinitionTemplateNumberNew = grib2_select_PDTN(
                         is_eps, is_instant,
                         is_chemical,
+                        is_chemical_srcsink,
                         is_chemical_distfn,
                         is_aerosol,
                         is_aerosol_optical);
