@@ -1,4 +1,4 @@
-# Copyright 2005-2018 ECMWF.
+# (C) Copyright 2005- ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -20,11 +20,20 @@ else
   echo
   echo "TEST: $0"
 
+  # Only Unix supported
+  ECCODES_ON_WINDOWS=0
+
   data_dir=""
   # save current working dir
   save=`pwd`
 
   set -x
+  EXEC=""
+  HAVE_MEMFS=0
+  HAVE_PNG=0
+  HAVE_EXTRA_TESTS=0
+  HAVE_JPEG=0
+  HAVE_AEC=0
 
   if [ -z "${data_dir}" ]
   then
@@ -63,6 +72,6 @@ else
 
   # go back to current working dir
   cd $save
-  set -u
+  # set -u
 fi
 
