@@ -33,12 +33,12 @@ grib_option grib_options[] = {
     { "i:", 0, 0, 0, 1, 0 }
 };
 
-const char* grib_tool_description =
+const char* tool_description =
     "Get values of some keys from a TAF file."
     "\n\tIt is similar to taf_ls, but fails returning an error code "
     "\n\twhen an error occurs (e.g. key not found).";
-const char* grib_tool_name  = "taf_get";
-const char* grib_tool_usage = "[options] file file ...";
+const char* tool_name  = "taf_get";
+const char* tool_usage = "[options] file file ...";
 
 int grib_options_count = sizeof(grib_options) / sizeof(grib_option);
 int mode               = 0;
